# Please keep this package in sync with FC

Name:           virt-what
Version:        1.25
Release:        %mkrel 1
Summary:        Detect if we are running in a virtual machine

Group:          System/Kernel and hardware
License:        GPLv2+
URL:            https://people.redhat.com/~rjones/virt-what/
Source0:        https://people.redhat.com/~rjones/virt-what/files/%{name}-%{version}.tar.gz

BuildRequires:  make
BuildRequires:  git
BuildRequires:  autoconf, automake, libtool
# for pod2man:
BuildRequires:  perl

# Required at build time in order to do 'make check' (for getopt).
BuildRequires:  util-linux

# virt-what script uses dmidecode and getopt (from util-linux).
# RPM cannot detect this so make the dependencies explicit here.
%ifarch aarch64 %{ix86} x86_64
Requires:       dmidecode
%endif
Requires:       util-linux

# Runs the 'which' program to find the helper.
Requires:       which


%description
virt-what is a shell script which can be used to detect if the program
is running in a virtual machine.

The program prints out a list of "facts" about the virtual machine,
derived from heuristics.  One fact is printed per line.

If nothing is printed and the script exits with code 0 (no error),
then it can mean either that the program is running on bare-metal or
the program is running inside a type of virtual machine which we don't
know about or can't detect.

Current types of virtualization detected:

 - alibaba_cloud      Alibaba cloud
 - alibaba_cloud-ebm
 - aws                Amazon Web Services
 - bhyve              FreeBSD hypervisor
 - docker             Docker container
 - google_cloud       Google cloud
 - hyperv             Microsoft Hyper-V
 - ibm_power-kvm      IBM POWER KVM
 - ibm_power-lpar_shared IBM POWER LPAR (hardware partition)
 - ibm_power-lpar_dedicated
 - ibm_systemz-*      IBM SystemZ Direct / LPAR / z/VM / KVM
 - illumos-lx         Illumos with Linux syscall emulation
 - ldoms              Oracle VM Server for SPARC Logical Domains
 - linux_vserver      Linux VServer container
 - lxc                Linux LXC container
 - kvm                Linux Kernel Virtual Machine (KVM)
 - lkvm               LKVM / kvmtool
 - nutanix_ahv        Nutanix Acropolis Hypervisor (AHV)
 - openvz             OpenVZ or Virtuozzo
 - ovirt              oVirt node
 - parallels          Parallels Virtual Platform
 - podman             Podman container
 - powervm_lx86       IBM PowerVM Lx86 Linux/x86 emulator
 - qemu               QEMU (unaccelerated)
 - redhat             Red Hat hypervisor
 - rhev               Red Hat Enterprise Virtualization
 - uml                User-Mode Linux (UML)
 - virtage            Hitachi Virtualization Manager (HVM) Virtage LPAR
 - virtualbox         VirtualBox
 - virtualpc          Microsoft VirtualPC
 - vmm                vmm OpenBSD hypervisor
 - vmware             VMware
 - xen                Xen
 - xen-dom0           Xen dom0 (privileged domain)
 - xen-domU           Xen domU (paravirtualized guest domain)
 - xen-hvm            Xen guest fully virtualized (HVM)


%prep
%autosetup -S git

# Always rebuild upstream autotools files.
autoreconf -i


%build
%configure
make

%install
%make_install


%check
if ! make -k check ; then
    find -name test-suite.log -exec cat {} \;
    exit 1
fi

%files
%doc README COPYING
%{_sbindir}/virt-what
%{_libexecdir}/virt-what-cpuid-helper
%{_mandir}/man1/*.1*



%changelog
* Wed Nov 09 2022 tv <tv> 1.25-1.mga9
+ Revision: 1904859
- New upstream version 1.25

* Wed Jun 29 2022 tv <tv> 1.24-1.mga9
+ Revision: 1866665
- New upstream version 1.24
- Update list of supported hypervisors
- Fix %%check for failures

* Fri Apr 15 2022 tv <tv> 1.22-1.mga9
+ Revision: 1850235
- New upstream version 1.21.

* Wed Mar 30 2022 umeabot <umeabot> 1.21-3.mga9
+ Revision: 1833565
- Mageia 9 Mass Rebuild

* Thu May 06 2021 tv <tv> 1.21-2.mga9
+ Revision: 1721674
- New upstream version 1.21.

* Wed Apr 14 2021 tv <tv> 1.21-1.mga9
+ Revision: 1715740
- Add all patches since 1.20 in preparation for 1.21 release.

* Sun Feb 16 2020 umeabot <umeabot> 1.20-2.mga8
+ Revision: 1534496
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Oct 04 2019 tv <tv> 1.20-1.mga8
+ Revision: 1449243
- new release

* Thu Nov 01 2018 tv <tv> 1.19-1.mga7
+ Revision: 1327047
- new release

* Sun Sep 23 2018 umeabot <umeabot> 1.18-3.mga7
+ Revision: 1301625
- Mageia 7 Mass Rebuild

* Wed Apr 11 2018 tv <tv> 1.18-2.mga7
+ Revision: 1217542
- Include upstream patches since 1.18 was released.
- dmidecode should also available on aarch64.

* Sun Sep 10 2017 tv <tv> 1.18-1.mga7
+ Revision: 1152426
- new release

* Fri Jan 22 2016 daviddavid <daviddavid> 1.15-2.mga6
+ Revision: 926412
- switch to %%configure2_5x to fix build

* Fri Sep 04 2015 tv <tv> 1.15-1.mga6
+ Revision: 872700
- new release

* Wed Oct 15 2014 umeabot <umeabot> 1.14-3.mga5
+ Revision: 749938
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.14-2.mga5
+ Revision: 690215
- Mageia 5 Mass Rebuild

* Wed Feb 19 2014 tv <tv> 1.14-1.mga5
+ Revision: 594938
- new release

* Fri Oct 18 2013 umeabot <umeabot> 1.12-2.mga4
+ Revision: 520949
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 tv <tv> 1.12-1.mga3
+ Revision: 388086
- imported package virt-what

